Introduction
============

.. image:: https://readthedocs.org/projects/adafruit-circuitpython-gfx/badge/?version=latest
    :target: https://docs.circuitpython.org/projects/gfx/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/adafruit/Adafruit_CircuitPython_Bundle/blob/main/badges/adafruit_discord.svg
    :target: https://adafru.it/discord
    :alt: Discord

.. image:: https://github.com/adafruit/Adafruit_CircuitPython_GFX/workflows/Build%20CI/badge.svg
    :target: https://github.com/adafruit/Adafruit_CircuitPython_GFX/actions
    :alt: Build Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

CircuitPython pixel graphics drawing library.

Important: This library will likely be deprecated soon. If you are looking to use a specific display, search the product name (i.e. ssd1322 or ili9341) at `https://github.com/adafruit/ <https://github.com/adafruit/>`_, or find it in the `circuitpython bundle <https://github.com/adafruit/Adafruit_CircuitPython_Bundle>`_.

Dependencies
=============
This driver depends on:

* `Adafruit CircuitPython <https://github.com/adafruit/circuitpython>`_

Please ensure all dependencies are available on the CircuitPython filesystem.
This is easily achieved by downloading
`the Adafruit library and driver bundle <https://github.com/adafruit/Adafruit_CircuitPython_Bundle>`_.

Usage Example
=============

See example in /examples/gfx_simpletest.py

Most displays now use displayio. You can find simpletests for specific displays in their respective repositories or in the examples section of the `circuitpython bundle <https://github.com/adafruit/Adafruit_CircuitPython_Bundle>`_

Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/adafruit/Adafruit_CircuitPython_GFX/blob/main/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.

Documentation
=============

For information on building library documentation, please check out `this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.
